@@ -6,25 +6,23 @@
 #' value.
 #'
 #' @param data_obj A S3 object including the following:
-#'   - Original data set + GPS values (Y, w, GPS, counter, row_index, c)
+#'   - Original data set + GPS values
 #'   - e_gps_pred
 #'   - e_gps_std_pred
 #'   - w_resid
 #'   - gps_mx (min and max of gps)
 #'   - w_mx (min and max of w).
 #' @param ci_appr Causal inference approach.
-#' @param gps_model Model type which is used for estimating GPS value, including
-#' parametric and non-parametric.
+#' @param gps_density Model type which is used for estimating GPS value,
+#' including `normal` and `kernel`.
 #' @param bin_seq Sequence of w (treatment) to generate pseudo population. If
 #' NULL is passed the default value will be used, which is
 #' `seq(min(w)+delta_n/2,max(w), by=delta_n)`.
+#' @param exposure_col_name Exposure data column name.
 #' @param nthread An integer value that represents the number of threads to be
 #' used by internal packages.
 #' @param ... Additional parameters.
 #'
-#' @note
-#' The input data set should be output of estimate_gps function with
-#' internal_use flag activated.
 #'
 #' @export
 #'
@@ -36,12 +34,10 @@
 #'
 #' set.seed(112)
 #' m_d <- generate_syn_data(sample_size = 100)
-#' data_with_gps <- estimate_gps(m_d$Y,
-#'                               m_d$treat,
-#'                               m_d[c("cf1","cf2","cf3","cf4","cf5","cf6")],
-#'                               pred_model = "sl",
-#'                               gps_model = "parametric",
-#'                               internal_use = TRUE,
+#' data_with_gps <- estimate_gps(m_d[, c("id", "Y")],
+#'                               m_d[, c("id", "w")],
+#'                               m_d[, c("id", "cf1","cf2","cf3","cf4","cf5","cf6")],
+#'                               gps_density = "normal",
 #'                               params = list(xgb_max_depth = c(3,4,5),
 #'                                        xgb_nrounds=c(10,20,30,40,50,60)),
 #'                               nthread = 1,
@@ -51,18 +47,19 @@
 #'
 #' pd <- compile_pseudo_pop(data_obj = data_with_gps,
 #'                          ci_appr = "matching",
-#'                          gps_model = "parametric",
+#'                          gps_density = "normal",
 #'                          bin_seq = NULL,
+#'                          exposure_col_name = c("w"),
 #'                          nthread = 1,
-#'                          matching_fun = "matching_l1",
+#'                          dist_measure = "l1",
 #'                          covar_bl_method = 'absolute',
 #'                          covar_bl_trs = 0.1,
 #'                          covar_bl_trs_type= "mean",
 #'                          delta_n = 0.5,
 #'                          scale = 1)
 #'
-compile_pseudo_pop <- function(data_obj, ci_appr, gps_model,
-                               bin_seq, nthread,
+compile_pseudo_pop <- function(data_obj, ci_appr, gps_density,
+                               bin_seq, exposure_col_name, nthread,
                                ...) {
 
   # Checking arguments
@@ -79,21 +76,24 @@ compile_pseudo_pop <- function(data_obj, ci_appr, gps_model,
   logger::log_info("Starting compiling pseudo population ",
                     " (original data size: {nrow(data_obj$dataset)}) ... ")
 
+  auxilary_columns <- c("e_gps_pred", "e_gps_std_pred", "w_resid")
   if (ci_appr == 'matching'){
       matched_set <- create_matching(data_obj,
+                                     exposure_col_name,
                                      bin_seq,
-                                     gps_model,
+                                     gps_density,
                                      nthread,
                                      ...)
       logger::log_info("Finished compiling pseudo population ",
                       " (Pseudo population data size: {nrow(matched_set)})")
+      matched_set[, (auxilary_columns) := NULL]
       return(matched_set)
 
   } else if (ci_appr == 'weighting'){
-
-    weighted_set <- create_weighting(data_obj$dataset, ...)
+    weighted_set <- create_weighting(data_obj$dataset, exposure_col_name, ...)
     logger::log_info("Finished compiling pseudo population ",
                      " (Pseudo population data size: {nrow(weighted_set)})")
+    weighted_set[, (auxilary_columns) := NULL]
     return(weighted_set)
 
   } else {
