@@ -9,10 +9,12 @@
 #' @param m_w A vector of continuous exposure variable in the matched set.
 #' @param counter_weight A vector of counter or weight variable in the matched
 #' set.
-#' @param bw_seq A vector of bandwidth values (Default is seq(0.2,2,0.2)).
+#' @param bw_seq A vector of bandwidth values.
 #' @param w_vals A vector of values that you want to calculate the values of
 #'  the ERF at.
 #' @param nthread The number of available cores.
+#' @param kernel_appr Internal kernel approach. Available options are `locpol`
+#' and `kernsmooth`.
 #'
 #' @details
 #' Estimate Functions Using Local Polynomial kernel regression.
@@ -35,9 +37,9 @@
 #'
 #' set.seed(697)
 #' m_d <- generate_syn_data(sample_size = 200)
-#' pseudo_pop <- generate_pseudo_pop(m_d$Y,
-#'                                   m_d$treat,
-#'                                   m_d[c("cf1","cf2","cf3",
+#' pseudo_pop <- generate_pseudo_pop(m_d[, c("id", "Y")],
+#'                                   m_d[, c("id", "w")],
+#'                                   m_d[, c("id", "cf1","cf2","cf3",
 #'                                         "cf4","cf5","cf6")],
 #'                                   ci_appr = "matching",
 #'                                   pred_model = "sl",
@@ -49,7 +51,7 @@
 #'                                   covar_bl_trs = 0.1,
 #'                                   covar_bl_trs_type="mean",
 #'                                   max_attempt = 1,
-#'                                   matching_fun = "matching_l1",
+#'                                   dist_measure = "l1",
 #'                                   delta_n = 1,
 #'                                   scale = 0.5)
 #'
@@ -63,9 +65,10 @@
 estimate_npmetric_erf<-function(m_Y,
                                 m_w,
                                 counter_weight,
-                                bw_seq=seq(0.2,2,0.2),
+                                bw_seq,
                                 w_vals,
-                                nthread) {
+                                nthread,
+                                kernel_appr = "locpol") {
 
   # function call
   fcall <- match.call()
@@ -78,6 +81,11 @@ estimate_npmetric_erf<-function(m_Y,
     stop("Output and treatment vectors should be double vectors.")
   }
 
+  if (!(kernel_appr %in% c("locpol", "kernsmooth"))){
+    stop(paste("Acceptible kernel_appr: `locpol` and `kernsmooth`",
+               "The provided value: ", kernel_appr))
+  }
+
   if (sum(counter_weight == 0) == length(counter_weight)) {
       counter_weight <- counter_weight + 1
       logger::log_debug("Giving equal weight for all samples.")
@@ -94,7 +102,8 @@ estimate_npmetric_erf<-function(m_Y,
 
   parallel::clusterExport(cl = cl,
                           varlist = c("estimate_hat_vals", "w_fun",
-                                      "generate_kernel", "smooth_erf"
+                                      "generate_kernel", "smooth_erf",
+                                      "kernel_appr"
                                       ),
                           envir = environment())
 
@@ -104,7 +113,9 @@ estimate_npmetric_erf<-function(m_Y,
                                      matched_Y = m_Y,
                                      matched_w = m_w,
                                      matched_cw = counter_weight,
-                                     w_vals = w_vals)
+                                     w_vals = w_vals,
+                                     x_eval = NULL,
+                                     kernel_appr = kernel_appr)
 
   parallel::stopCluster(cl)
 
@@ -114,15 +125,21 @@ estimate_npmetric_erf<-function(m_Y,
 
   logger::log_info("The band width with the minimum risk value: {h_opt}.")
 
-  data <- data.frame(m_Y = m_Y, m_w = m_w)
-  tmp_loc <- locpol::locpol(formula = m_Y ~ m_w,
-                            data = data,
-                            bw = h_opt,
-                            weig = counter_weight,
-                            xeval = w_vals,
-                            kernel = locpol::gaussK)
-
-  erf <- tmp_loc$lpFit$m_Y
+  if (kernel_appr == "locpol"){
+    erf <- smooth_erf_locpol(matched_Y = m_Y,
+                             matched_w = m_w,
+                             matched_cw = counter_weight,
+                             x_eval = w_vals,
+                             bw = h_opt)
+  } else if (kernel_appr == "kernsmooth"){
+    erf <- smooth_erf_kernsmooth(matched_Y = m_Y,
+                                 matched_w = m_w,
+                                 matched_cw = counter_weight,
+                                 x_eval = w_vals,
+                                 bw = h_opt)
+  } else {
+    stop(paste("`kernel_appr`: ", kernel_appr, " is not supported."))
+  }
 
   if (sum(is.na(erf)) > 0){
     logger::log_debug("erf has {sum(is.na(erf))} missing values.")
